=======
Credits
=======

Development Lead
----------------

* Nahum Shalman <nshalman@omniti.com>

Contributors
------------

* Daniel Steinbrook <steinbro@post.harvard.edu>
* Adam Števko  <adam.stevko@gmail.com>
